# uCALC FOR SIMPLE CALCULATIONS OF NUMBERS LIST
---

### This is a library of simple math operations.
--- 



- You can pass a list of values ​​so that it returns a result.

- Use the methods (*some_all, subtract_all, multiply_all, divide_all*).

- The calculation is done in the order sent.